/*
	Description: Constructs the average increase in import exposure experienced by each commuting zone

	Author: Brendan Price
	Updated: July 31, 2014
	
	Note: The script "cbp_co_reader.do" must be executed before this program is run.
*/

version 12.1
set more off

local cleandir "../../../dta/cbp/county/clean"
local tradedir "../../../dta/trade"

/* Construct CZ-level changes in import penetration */

foreach g in "us" "ot" {
	foreach t in "1991_1999" "1991_2007" "1991_2011" "1999_2007" "1999_2011" {
		local start = substr("`t'", 1, 4)
		local end = substr("`t'", 6, 4)

		* Load cleaned CZ-level data
		use "`cleandir'/emp_counts/cbp_czone_merged.dta", clear

		* Specify the year in which we compute employment shares
		if "`g'" == "us" {
			keep if year == `start'
		}
		else if "`g'" == "ot" {
			keep if year == 1988
		}

		* Compute industry employment shares
		bysort czone year: egen czone_emp = total(emp)
		gen empshare = emp/czone_emp
		drop emp czone_emp

		* Merge in each industry's change in import exposure
		merge m:1 sic87dd using "`tradedir'/trade_variables.dta", assert(1 3) keepusing(d_import_`g'ch_`t')
		assert sic87dd < 2000 | sic87dd > 3999 if _merge == 1

		* Define non-manufacturing changes in import exposure as zero
		replace d_import_`g'ch_`t' = 0 if _merge == 1
		drop _merge
		
		* Calculate average changes in import exposure
		collapse (mean) d_czone_imp_exp_`g'ch_`t' = d_import_`g'ch_`t' [aw = empshare], by(czone year)

		if "`g'" == "us" {
			label var d_czone_imp_exp_`g'ch_`t' "Change in CZ's average import exposure, `start'-`end'"
		}
		else if "`g'" == "ot" {
			label var d_czone_imp_exp_`g'ch_`t' "Instrument for change in CZ's average import exposure, `start'-`end'"
		}
		
		* Save the shocks
		tempfile d_czone_imp_exp_`g'ch_`t'
		save "`d_czone_imp_exp_`g'ch_`t''.dta", replace
	}
}

* Combine the various changes in CZ import exposure into a single file
use "`d_czone_imp_exp_usch_1991_1999'.dta", clear
merge 1:1 czone using "`d_czone_imp_exp_usch_1991_2007'.dta", assert(3) nogenerate
merge 1:1 czone using "`d_czone_imp_exp_usch_1991_2011'.dta", assert(3) nogenerate
merge 1:1 czone using "`d_czone_imp_exp_usch_1999_2007'.dta", assert(3) nogenerate
merge 1:1 czone using "`d_czone_imp_exp_usch_1999_2011'.dta", assert(3) nogenerate

merge 1:1 czone using "`d_czone_imp_exp_otch_1991_1999'.dta", assert(3) nogenerate
merge 1:1 czone using "`d_czone_imp_exp_otch_1991_2007'.dta", assert(3) nogenerate
merge 1:1 czone using "`d_czone_imp_exp_otch_1991_2011'.dta", assert(3) nogenerate
merge 1:1 czone using "`d_czone_imp_exp_otch_1999_2007'.dta", assert(3) nogenerate
merge 1:1 czone using "`d_czone_imp_exp_otch_1999_2011'.dta", assert(3) nogenerate

compress
save "`cleandir'/shocks/czone_import_shocks.dta", replace


