/*
	Description: Creates Appendix Figure 1 (scatter plot of the first-stage relationship between import shocks)

	Author: Brendan Price
	Updated: July 30, 2014
*/

version 12.1
set more off
clear all
capture restore, not
set scheme s1color

local outdir "../../out"

* Load the estimation sample
use "../../dta/sample/main.dta", clear

* Restrict to manufacturing and to variables needed
keep if manuf == 1
keep sic87dd sic3 cbp_emp1991 d_import_usch_1991_2011 d_import_otch_1991_2011

/* Plot the first stage relationship between Chinese import penetration and its instrument */

* Specify weighting and clustering
local aw "[aw = cbp_emp1991]"
local vce "vce(cluster sic3)"

* Best fit lines
quietly reg d_import_usch_1991_2011 d_import_otch_1991_2011 `aw', `vce'
local b = _b[d_import_otch_1991_2011]
local a = _b[_cons]
local se = _se[d_import_otch_1991_2011]
local r2 = e(r2)

di "FIRST STAGE REGRESSION"
di "Coefficient: `=string(`b', "%9.2f")'"
di "Standard error: `=string(`se', "%9.2f")'"
di "R-squared: `=string(`r2', "%9.2f")'"

predict yhat, xb
predict s, stdp

gen yhat_high = yhat + (1.96 * s)
gen yhat_low = yhat - (1.96 * s)

* Make sure that we aren't truncating any points
assert d_import_otch_1991_2011 >= -1 & d_import_otch_1991_2011 <= 9
assert d_import_usch_1991_2011 >= -1 & d_import_usch_1991_2011 <= 11

* Scatter plot
#delimit ;
graph twoway (rarea yhat_low yhat_high d_import_otch_1991_2011, sort color(gs14))
	(scatter d_import_usch_1991_2011 d_import_otch_1991_2011, msize(small) mcolor(navy))
	(function y = `a' + (`b' * x), range(d_import_otch_1991_2011) clcolor(maroon) clpat(solid)),
	title("")
	xtitle("100 x Annual Change in Comparison Countries' Exposure", size(medsmall))
	ytitle("100 x Annual Change in U.S. Exposure", size(medsmall))
	ylabel(-1(1)11, angle(0) labsize(medsmall) grid)
	ymtick(-1(.5)11)
	xlabel(-1(1)9, labsize(medsmall))
	xmtick(-1(.5)9)
	legend(rows(2) order(2 3 1) size(medsmall)
		label(1 "95% Confidence Interval")
		label(2 "Change in Import Exposure")
		label(3 "Fitted Values"));
#delimit cr

graph export "`outdir'/figs/AppFig1.eps", as(eps) replace
!epstopdf --outfile="`outdir'/figs/AppFig1.pdf" "`outdir'/figs/AppFig1.eps"


