/*
	Description: Creates Table 7 (measuring effects of import shocks on employment in commuting zones)

	Author: Brendan Price
	Updated: July 31, 2014
*/

version 12.1
clear all
set more off
set matsize 11000

* Directory paths
local cleandir "../../dta/cbp/county/clean"
local outdir "../../out"

* Partial R-squared used to "discount" implied employment changes
local pfactor = .56

* Locals to be used later
local regions "region2 region3 region4 region5 region6 region7 region8 region9"

* Predict implied employment change
capture program drop compute_changes
program define compute_changes
	* Predict implied employment change by exposure/tradability class
	forvalues i = 1/3 {
		* Full period
		egen tot_pred_class`i' = total(pred_d_emp * (class == `i'))
		
		* Subperiods
		forvalues k = 1/2 {
			egen t`k'_tot_pred_class`i' = total(pred_d_emp * t`k' * (class == `i'))
		}
	}

	* Predict implied employment change in total by time period
	egen t1_tot_pred = total(pred_d_emp * t1)
	egen t2_tot_pred = total(pred_d_emp * t2)
	egen tot_pred = total(pred_d_emp)

	* Report implied employment change alongside spec
	foreach d in t1_tot_pred t2_tot_pred tot_pred t1_tot_pred_class1 t1_tot_pred_class2 t1_tot_pred_class3 t2_tot_pred_class1 t2_tot_pred_class2 t2_tot_pred_class3 tot_pred_class1 tot_pred_class2 tot_pred_class3 {
		quietly sum `d', meanonly
		estadd scalar `d' = r(mean)
		drop `d'
	}

	replace pred_d_emp = 0
end

/* Merge together CZ-level variables */

* Employment counts
use "`cleandir'/emp_counts/cbp_czone_merged.dta", clear
keep if year == 1991 | year == 1999 | year == 2007 | year == 2011

* Compute total emp and mfg emp
gen mfgemp = emp if sic87dd >= 2000 & sic87dd <= 3999
collapse (sum) mfgemp (sum) totemp = emp, by(year czone)
reshape wide mfgemp totemp, i(czone) j(year)
order czone totemp* mfgemp*
tempfile empcounts
save "`empcounts'.dta", replace

* Regional population from the Census Population Estimates
use "../../dta/popest/clean/czone_pop_1990_2012.dta", clear
keep if year == 1991 | year == 1999 | year == 2007 | year == 2011
rename totpop pop
reshape wide pop workagepop, i(czone) j(year)
order czone pop* workagepop*
tempfile popest
save "`popest'.dta", replace

use "`empcounts'.dta", clear
merge 1:1 czone using "`popest'.dta", assert(3) nogenerate

* Regional import shocks (annualized)
merge 1:1 czone using "`cleandir'/shocks/czone_import_shocks.dta", assert(3) nogenerate keepusing(*1991_1999 *1999_2011 *1999_2007) 

foreach g in "us" "ot" {
	foreach t in "1991_1999" "1999_2011" "1999_2007" {
		local start = substr("`t'", 1, 4)
		local end = substr("`t'", 6, 4)

		gen shock_`g'_`t' = d_czone_imp_exp_`g'ch_`t'/(`end' - `start')
	}
}

* Region dummies
merge 1:1 czone using "../../xwalks/geo/cw_czone_region.dta", assert(2 3) keep(3) keepusing(region)
tab region, gen(region)

* Compute baseline manufacturing shares
gen mfgsh1991 = mfgemp1991 / totemp1991
gen mfgsh1999 = mfgemp1999 / totemp1999
assert mfgsh1991 != .
assert mfgsh1999 != .

* Restrict to variables we wish to retain
keep czone pop1991 workagepop* shock_us_* shock_ot_* region* mfgsh1991 mfgsh1999

tempfile czdata
save "`czdata'.dta", replace

* Run specs investigating effects on (1) overall employment and (2) employment in exposed and non-exposed sectors
foreach exercise in "overall" "sectoral" {
	/*
		Compute employment within industry classes defined on the basis of exposure and tradability:
		(1) Exposed: precise definition depends on the "exercise"
		(2) Non-Exposed Tradable
		(3) Non-Exposed Non-Tradable
	 */

	use "`cleandir'/emp_counts/cbp_czone_merged.dta", clear
	keep if year == 1991 | year == 1999 | year == 2007 | year == 2011
	merge m:1 sic87dd using "`cleandir'/classification/industry_classification.dta", assert(3) nogenerate

	gen class = .
	if "`exercise'" == "overall" {
		replace class = 0
		local classes "class0"
	}
	else if "`exercise'" == "sectoral" {
		replace class = 1 if exposed_directly == 1 | exposed_upstream == 1
		replace class = 2 if (exposed_directly == 0 & exposed_upstream == 0) & tradable == 1
		replace class = 3 if (exposed_directly == 0 & exposed_upstream == 0) & tradable == 0
		local classes "class1 class2 class3"
	}

	assert class != .
	
	* Convert to one observation per CZ per class
	collapse (sum) emp, by(czone class year)
	fillin czone class year
	assert _fillin == 0
	drop _fillin

	reshape wide emp, i(czone class) j(year)
	forvalues i = 0/3 {
		gen class`i' = class == `i'
	}
	
	* Merge in CZ-level data
	merge m:1 czone using "`czdata'.dta", assert(3) nogenerate

	* Compute (annualized) changes in employment/population
	foreach y in 1991 1999 2007 2011 {
		gen emppop_`y' = 100 * (emp`y'/workagepop`y')
	}

	foreach t in "1991_1999" "1999_2011" "1999_2007" {
		local start = substr("`t'", 1, 4)
		local end = substr("`t'", 6, 4)

		gen d_emppop_`t' = (emppop_`end' - emppop_`start')/(`end' - `start')
	}

	* Convert to one observation per CZ per class per period
	keep czone class* region* mfgsh1991 mfgsh1999 pop1991 workagepop* *1991_1999 *1999_2011 *1999_2007
	reshape long d_emppop_ shock_us_ shock_ot_, i(czone class) j(period) string
	assert period == "1991_1999" | period == "1999_2011" | period == "1999_2007"

	rename d_emppop_ d_emppop
	rename shock_us_ shock_us
	rename shock_ot_ shock_ot
	
	* Time period dummies
	gen t1 = (period == "1991_1999")
	gen t2 = (period == "1999_2011") | (period == "1999_2007")

	* For 1991-1999, control for 1991 mfg share; for 1999-2011 and 1999-2007, control for 1999 mfg share
	gen mfgsh = mfgsh1991 if period == "1991_1999"
	replace mfgsh = mfgsh1999 if period == "1999_2011" | period == "1999_2007"
	drop mfgsh1991 mfgsh1999
	
	* Fully interact classes with RHS variables
	forvalues c = 0/3 {
		* Class x period interactions
		gen t1_class`c' = t1 * class`c'
		gen t2_class`c' = t2 * class`c'
	
		* Class x shock interactions
		gen shock_us_class`c' = shock_us * class`c'
		gen shock_ot_class`c' = shock_ot * class`c'
		
		* Class x manufacturing share interactions
		gen mfgsh_class`c' = mfgsh * class`c'
		
		* Class x region interactions
		local regions_class`c' ""
		foreach r of local regions {
			gen `r'_class`c' = `r' * class`c'
			local regions_class`c' "`regions_class`c'' `r'_class`c'"
		}
	}

	* Label the shock variables: only matters on the final iteration
	if "`exercise'" == "sectoral" {
		label var shock_us_class0 "D[IPW_i]"
		label var shock_us_class1 "D[IPW_i] x (Exposed)"
		label var shock_us_class2 "D[IPW_i] x (Non-Exposed Tradable)"
		label var shock_us_class3 "D[IPW_i] x (Non-Exposed Non-Tradable)"	
	}
	
	* Dependent variable
	local yvar "d_emppop"

	* Weighting, clustering, and controls
	local aw "[aw = pop1991]"
	local options "noconstant vce(cluster czone)"
	
	* Specifications
	if "`exercise'" == "overall" {
		assert class == 0

		* First model in this exercise
		local k = 1

		* Specification details
		local time_effects "t1_class0 t2_class0"
		local mfgsh_effects "mfgsh_class0"
		local region_effects "`regions_class0'"
		local shocks "shock_us_class0"
		local instruments "shock_ot_class0"
	}
	else if "`exercise'" == "sectoral" {
		assert class == 1 | class == 2 | class == 3
		
		* First model in this exercise
		local k = 4

		* Specification details
		local time_effects "t1_class1 t1_class2 t1_class3 t2_class1 t2_class2 t2_class3"
		local mfgsh_effects "mfgsh_class1 mfgsh_class2 mfgsh_class3"
		local region_effects "`regions_class1' `regions_class2' `regions_class3'"
		local shocks "shock_us_class1 shock_us_class2 shock_us_class3"
		local instruments "shock_ot_class1 shock_ot_class2 shock_ot_class3"
	}

	* Specify population count used in predicting employment changes
	gen popvar = workagepop1999 if period == "1991_1999"
	replace popvar = workagepop2011 if period == "1999_2011"
	replace popvar = workagepop2007 if period == "1999_2007"
	assert popvar != .

	* Factor needed to rescale coefficients (to undo multiplication by 100 and also annualization)
	gen lambda = 100 / (1999 - 1991) if period == "1991_1999"
	replace lambda = 100 / (2011 - 1999) if period == "1999_2011"
	replace lambda = 100 / (2007 - 1999) if period == "1999_2007"
	assert lambda != .

	* Variable for storing predicted employment losses
	gen pred_d_emp = 0

	tempfile core
	save "`core'.dta", replace
	
	* Specs for the period 1991-2011
	use "`core'.dta", clear
	keep if period == "1991_1999" | period == "1999_2011"
	
	eststo m`k': ivregress 2sls `yvar' `time_effects' (`shocks' = `instruments') `aw', `options'
	eststo m`=`k'+1': ivregress 2sls `yvar' `time_effects' `mfgsh_effects' (`shocks' = `instruments') `aw', `options'
	eststo m`=`k'+2': ivregress 2sls `yvar' `time_effects' `mfgsh_effects' `region_effects' (`shocks' = `instruments') `aw', `options'
	
	* Compute employment changes implied by column (6)
	if "`exercise'" == "sectoral" {
		estimates restore m6
		foreach shock of local shocks {
			replace pred_d_emp = pred_d_emp + (popvar * (1/lambda) * `shock' * ((_b[`shock'] * `pfactor')))
		}
		compute_changes
	}
	
	* Specs for the period 1991-2007
	use "`core'.dta", clear
	keep if period == "1991_1999" | period == "1999_2007"

	if "`exercise'" == "overall" {
		local mn "m7"
	}
	else if "`exercise'" == "sectoral" {
		local mn "m8"
	}
	
	eststo `mn': ivregress 2sls `yvar' `time_effects' `mfgsh_effects' `region_effects' (`shocks' = `instruments') `aw', `options'

	* Compute employment changes implied by column (8)
	if "`exercise'" == "sectoral" {
		estimates restore m8
		foreach shock of local shocks {
			replace pred_d_emp = pred_d_emp + (popvar * (1/lambda) * `shock' * ((_b[`shock'] * `pfactor')))
		}
		compute_changes			
	}
}

* Report regression results
tempfile specs

#delimit ;
esttab m1 m2 m3 m4 m5 m6 m7 m8 using "`specs'.csv",
	nodepvars
	collabels(none)
	mlabels(none)
	b(%9.2f) se(%9.2f)
	star(* .10 ** .05 *** .01)
	nonotes
	label
	indicate("Sector x Time Effects = t1* t2*" "Sector x Mfg Emp Share at Baseline = mfgsh*" "Sector x Census Division Dummies = region*")
	order(shock_us_class0 shock_us_class1 shock_us_class2 shock_us_class3)
	stats(N	t1_tot_pred t2_tot_pred tot_pred t1_tot_pred_class1 t1_tot_pred_class2 t1_tot_pred_class3 t2_tot_pred_class1 t2_tot_pred_class2 t2_tot_pred_class3 tot_pred_class1 tot_pred_class2 tot_pred_class3, labels("N" "Overall, 1991-1999" "Overall, 1999-2011"  "Overall, 1991-2011" "Exposed Industries, 1991-1999" "Non-Exposed Tradable Industries, 1991-1999" "Non-Exposed Non-Tradable Industries, 1991-1999" "Exposed Industries, 1999-2011" "Non-Exposed Tradable Industries, 1999-2011" "Non-Exposed Non-Tradable Industries, 1999-2011" "Exposed Industries, 1991-2011" "Non-Exposed Tradable Industries, 1991-2011" "Non-Exposed Non-Tradable Industries, 1991-2011") fmt(0))
	replace;
#delimit cr

* Switch the output to Excel format
insheet using "`specs'.csv", comma clear
export excel "`outdir'/AADHP-JOLE-Tables.xlsx", sheetreplace sheet(Tab7_Raw)

