/*
	Description: Processes the 1992 BEA benchmark input-output tables
	
	Author: Brendan Price, modified from Gordon Hanson's file china_inputs_9107.do
	Updated: February 1, 2015

	Useful observations for understanding this file:
	- I combine the "make" and "use" tables to map commodities into (upstream/supplying) industries.
	- In the BEA input-output tables, multiple SIC industries may be identified with the same commodity. For manufacturing industries, we use "vship" (value of shipments) to determine output shares when multiple SIC industries are associated with the same output commodity. We use "matcost" (materials costs) to determine input shares when multiple SIC industries use the same input commodity. Since the NBER-CES dataset does not cover non-manufacturing industries, we cannot do the same thing for non-manufacturing. We get around this problem by aggregating non-manufacturing industries to the point where there are no remaining cases of overlap.
	- Nomenclature: sic87_down denotes industries purchasing the good; sic87_up denotes industries producing the good.
	- The "use" table includes commodities produced by non-manufacturing industries, and also commodities purchased by non-manufacturing industries. We disregard the former but incorporate the latter. Loosely, we ignore haircuts but account for scissors purchases by barbers. This asymmetry can be justified by noting that we would measure zero change in US imports of Chinese haircuts, so that there is no downstream effect arising from trade exposure experienced by non-manufacturing industries.
*/

version 12.1
set more off
set matsize 11000
clear all

local iodir "../../../dta/io"

/* Prepare 1992 data from the NBER-CES database for later use */

use "../../../dta/nberces/src/sic5809.dta", clear
assert sic >= 2000 & sic <= 3999
keep if year == 1992
keep sic matcost energy vship
rename sic sic87
sort sic87
tempfile x0
save "`x0'.dta", replace

/* Prepare the "use" file */

* Load the source data
insheet commodity industry refnum use_value margins railcost truckcost watercost aircost oilpipecost gaspipecost wholesale retail using "`iodir'/src/IOUSE.TXT", tab clear

* Drop the leading zero in "industry" for comparability with Gordon Hanson's earlier file
replace industry = regexr(industry, "^0", "")

* Verify that margins (transportation costs, wholesale and retail margins) are a component of use values
assert sign(margins) == sign(use_value) if margins != 0
assert abs(margins) <= abs(use_value)

tempfile use_table
save "`use_table'.dta", replace

/* Prepare the "make" file */

* Load the source data
insheet industry commodity refnum make_value using "`iodir'/src/IOMAKE.TXT", tab clear
assert refnum == 1
drop refnum

tempfile make_table
save "`make_table'.dta", replace

/*
	Compute the share of each BEA commodity produced by each BEA industry
	
	NB: two aberrations have negative values, leading to shares that lie outside 0 and 1.
	I allow this because it's needed to make both sides of the ledger balance later on in the "use" file.
*/

* Create a mapping from commodities into (upstream) industries
use "`make_table'.dta", clear
bysort commodity: egen commodity_sum = total(make_value)
gen share = make_value/commodity_sum
keep commodity industry share
keep if (share != 0 & share != .) | (commodity == industry)
replace share = 1 if (share == .) & (commodity == industry)
assert (share >= 0 & share <= 1) | (industry == 850000 & commodity == 850000) | ((industry == 780500 | industry == 700400) & commodity == 700400)
bysort commodity: egen totshare = total(share)
assert abs(1 - totshare) < .00001
drop totshare
rename industry industry_up
tempfile shares
save "`shares'.dta", replace

/* Process the "use" table */

* Load the "use" table, showing purchases of I/O commodities by I/O industries in 1992
use "`use_table'.dta", clear

* Retain "use values" which encompass transportation costs and wholesale/retail markups
keep commodity industry use_value

* Note that industry-commodity pairs uniquely identify observations
bysort commodity industry: assert _N == 1

* Record the magnitude of total transaction flows in the raw file
egen tot_use_value0 = total(abs(use_value))

* Recode non-numeric I/O codes pertaining to federal, state, and local government expenditures
replace industry = "1000001" if industry == "9600I0"
replace industry = "1000002" if industry == "9600C0"
replace industry = "1000003" if industry == "9700I0"
replace industry = "1000004" if industry == "9700C0"
replace industry = "1000005" if industry == "9800I1"
replace industry = "1000006" if industry == "9800I2"
replace industry = "1000007" if industry == "9800I3"
replace industry = "1000008" if industry == "9800C1"
replace industry = "1000009" if industry == "9800C2"
replace industry = "1000010" if industry == "9800C3"
replace industry = "1000011" if industry == "9910I1"
replace industry = "1000012" if industry == "9910I2"
replace industry = "1000013" if industry == "9910I3"
replace industry = "1000014" if industry == "9910I4"
replace industry = "1000015" if industry == "9910C1"
replace industry = "1000016" if industry == "9910C2"
replace industry = "1000017" if industry == "9910C4"
replace industry = "1000018" if industry == "9920I1"
replace industry = "1000019" if industry == "9920I2"
replace industry = "1000020" if industry == "9920I3"
replace industry = "1000021" if industry == "9920C1"
replace industry = "1000022" if industry == "9920C2"
replace industry = "1000023" if industry == "9920C3"
replace industry = "1000024" if industry == "9930I1"
replace industry = "1000025" if industry == "9930I2"
replace industry = "1000026" if industry == "9930I3"
replace industry = "1000027" if industry == "9930I4"
replace industry = "1000028" if industry == "9930I5"
replace industry = "1000029" if industry == "9930I6"
replace industry = "1000030" if industry == "9930I7"
replace industry = "1000031" if industry == "9930I8"
replace industry = "1000032" if industry == "9930I9"
replace industry = "1000033" if industry == "9930C1"
replace industry = "1000034" if industry == "9930C8"
replace industry = "1000035" if industry == "9930C9"
destring industry, replace
sort industry

* Use the "make" table to proportionally map commodities into upstream industries
rename industry industry_down
joinby commodity using "`shares'.dta", unmatched(both) _merge(_merge)
assert commodity == 880000 | commodity == 890000 | commodity == 900000 if _merge == 1
assert commodity == industry_up if _merge == 2

replace industry_up = commodity if _merge == 1
replace share = 1 if _merge == 1
drop if _merge == 2

foreach v of varlist * {
	assert `v' != .
}

replace use_value = use_value * share
collapse (sum) use_value (mean) tot_use_value0, by(industry_down industry_up)

* Swap producer and consumer in cases of negative use values (most commonly imports)
sum use_value if industry_down == 950000, detail
gen flag = (use_value < 0)
gen x = industry_up if flag == 1
gen y = industry_down if flag == 1
replace industry_up = y if flag == 1
replace industry_down = x if flag == 1
replace use_value = -use_value if flag == 1
sum use_value if flag == 1
assert use_value >= 0
drop x y flag

tempfile edited_use
save "`edited_use'.dta", replace

/* Sanity check: within each industry, total sales should equal total factor payments (including pure profits) */

foreach d in "down" "up" {
	use "`edited_use'.dta", clear
	collapse (sum) use_`d' = use_value, by(industry_`d')
	rename industry_`d' industry
	tempfile total_flows_`d'
	save "`total_flows_`d''.dta", replace
}

use "`total_flows_down'.dta", clear
merge 1:1 industry using "`total_flows_up'.dta"
assert _merge == 3 if industry <= 850000
keep if industry <= 850000
assert abs(use_up - use_down) < 1

/* Combine BEA industries that correspond to overlapping SIC codes */

use "`edited_use'.dta", clear

foreach v of varlist industry_up industry_down {
	* Pool construction industries
	replace `v' = 110101 if `v' == 110102 | `v' == 110105 | `v' == 110108 | `v' == 110400 | `v' == 110501 | `v' == 110800 | `v' == 110900 | `v' == 120101 | `v' == 120214 | `v' == 120300

	* Pool petroleum industries
	replace `v' = 080001 if `v' == 070000 | `v' == 090004 | `v' == 110601 | `v' == 110602 | `v' == 110603 | `v' == 120215

	* Pool natural gas industries
	replace `v' = 680201 if `v' == 680202

	* Pool water/sanitary service industries
	replace `v' = 680301 if `v' == 680302
}

collapse (sum) use_value (mean) tot_use_value0, by(industry_up industry_down)

* Fill in missing supplier/customer pairs
fillin industry_up industry_down
replace use_value = 0 if _fillin == 1
drop _fillin

* Again compute total transaction flows
egen tot_use_value1 = total(use_value)
assert abs(1 - tot_use_value1/tot_use_value0) < .001 if tot_use_value0 != .
drop tot_use_value0
rename tot_use_value1 tot_use_value

tempfile x1
save "`x1'.dta", replace

/*
	PURCHASING INDUSTRIES:

	Calculate which commodities are purchased by which SIC industries (converting BEA industries to SIC industries).
	Convert SIC industry codes to I/O industry codes, where "industry_down" denotes the industry that is purchasing inputs.
	
	Note that 40 BEA manufacturing industries are composed of multiple SIC industries. We will divide each BEA industry's purchases across the SIC industries that compose the industry using the SIC industry's materials purchases from the NBER data.
*/

* Load the mapping from 1987 SIC industries to BEA industry codes
use "../../../xwalks/ind/sic2io/sic2io.dta", clear

* Merge in industry-level data from the NBER productivity dataset
merge 1:1 sic87 using "`x0'.dta", assert(1 3) gen(nber_merge)
assert nber_merge == 1 if manuf == 0
assert nber_merge == 3 if manuf == 1
drop nber_merge

rename io industry_down
rename sic87 sic87_down

* Merge in the use data
joinby industry_down using "`x1'.dta", unmatched(both)

* Note that some 'using' observations don't appear in the 'master' file.
* These can be thought of as commodity purchases by residual industries (e.g. owner-occupied housing, government sector)
assert _merge == 2 | _merge == 3
drop _merge

* Identify industries that match to multiple SICs (note: by earlier pooling, this occurs only within manufacturing)
bysort industry_down industry_up: gen num_sics = _N
tab industry_down if num_sics > 1
assert manuf == 1 if num_sics > 1

* Compute total materials costs/energy costs for NBER industries that comprise each BEA industry
bysort industry_down industry_up: egen tot_mat = total(matcost)
bysort industry_down industry_up: egen tot_energy = total(energy)
bysort industry_down industry_up: egen tot_netmat = total(matcost - energy)

assert matcost > 0 & matcost < . if num_sics > 1
assert energy > 0 & energy < . if num_sics > 1
assert (matcost - energy) > 0 & (matcost - energy) < . if num_sics > 1

* Tag industries corresponding to NBER variable "matcost": agricultural produce, minerals, manufactured goods, wholesale
gen comm_mat = ((industry_up < 040000) | (industry_up >= 050000 & industry_up <= 100000 & industry_up != 070000 & industry_up != 080001) | (industry_up >= 130000 & industry_up < 650000) | (industry_up == 690100))

* Tag commodities corresponding to NBER variable "energy": coal/petroleum, electricity, gas (note: I depart from Dorn here)
gen comm_energy = (industry_up == 070000 | industry_up == 080001 | industry_up == 680100 | industry_up == 680202 | industry_up == 680301)

* Apportion each I/O industry's commodity purchases to the associated SIC codes on the basis of their material/energy costs
replace use_value = use_value * ((matcost - energy)/tot_netmat) if (num_sics > 1) & (comm_mat == 1)
replace use_value = use_value * (energy/tot_energy) if (num_sics > 1) & (comm_energy == 1)
replace use_value = use_value * (matcost/tot_mat) if (num_sics > 1) & (comm_mat == 0 & comm_energy == 0)

* Verify that total transactions still agree with the number computed earlier
egen tot_use_value_check = total(use_value)
assert tot_use_value_check == tot_use_value
sum tot_use_value tot_use_value_check
drop tot_use_value_check

* Obtain a mapping between purchasing industries and the industries they purchase from
collapse (sum) use_value (mean) manuf (mean) tot_use_value, by(sic87_down industry_up)
assert manuf == 0 | manuf == 1 if manuf != .
fillin sic87_down industry_up
assert _fillin == 0
drop _fillin
sort industry_up
save "`x1'.dta", replace

/*
	PRODUCING INDUSTRIES:
	
	Merge to obtain the SIC identities of the supplying industries.
	The result is a matrix indicating gross bilateral commodity flows between 4-digit SIC industries (sic87dd)
*/

* As before, load SIC-BEA industry crosswalk and merge in industry characteristics from the NBER productivity database
use "../../../xwalks/ind/sic2io/sic2io.dta", clear

merge 1:1 sic87 using "`x0'.dta", gen(nber_merge)
assert nber_merge == 1 if manuf == 0
assert nber_merge == 3 if manuf == 1
drop nber_merge

rename io industry_up
rename sic87 sic87_up

* Merge with the earlier mapping between purchasing industries and their upstream suppliers
joinby industry_up using "`x1'.dta", unmatched(both)
assert _merge == 2 | _merge == 3
drop _merge

* Note that we retain observations (where sic87_down == .) representing final demand (+ purchases by "residual" industries)
count if sic87_down == .

* Identify upstream BEA industries that match to multiple SIC industries (by earlier pooling, occurs only within manufacturing)
bysort sic87_down industry_up: gen num_sics = _N
tab industry_up if num_sics > 1
assert manuf == 1 if num_sics > 1

* Allocate production of each upstream BEA industry to the associated SIC codes on the basis of their shipment values
assert vship > 0 & vship < . if num_sics > 1
bysort sic87_down industry_up: egen tot_vship = total(vship)
replace use_value = use_value * (vship/tot_vship) if num_sics > 1

* Obtain a mapping from purchasing industries sic87_down to producing industries sic87_up
collapse (sum) use_value (mean) tot_use_value, by(sic87_down sic87_up)

* Verify that total transaction volume continues to be unchanged
egen tot_use_value_check = total(use_value)
assert tot_use_value_check == tot_use_value
drop tot_use_value_check

sort sic87_up
save "`x1'.dta", replace

* Collapse to sic87dd codes
rename sic87_down sic87
do "../../../xwalks/ind/sic87_sic87dd/sic87_sic87dd.do"
rename sic87dd sic87dd_down
drop sic87

rename sic87_up sic87
do "../../../xwalks/ind/sic87_sic87dd/sic87_sic87dd.do"
rename sic87dd sic87dd_up
drop sic87

collapse (sum) use_value, by(sic87dd_down sic87dd_up)

fillin sic87dd_down sic87dd_up
replace use_value = 0 if _fillin == 1
drop _fillin

* Reorder/rename/label for clarity
order sic87dd_up sic87dd_down use_value
rename use_value gross_flows

label var sic87dd_up "SIC industry producing the commodity"
label var sic87dd_down "SIC industry purchasing the commodity"
label var gross_flows "Value of gross flows from upstream industry to downstream industry in 1992"

* Save a dataset containing gross bilateral flows between industries
compress
save "`iodir'/clean/flows/gross_flows.dta", replace

/*
	Compute output and input shares needed for the construction of upstream and downstream exposure measures.
	Note that observations with sic87dd_down or sic87dd_up missing correspond to a residual industry category.
*/

* Calculate total sales made by each industry
use "`iodir'/clean/flows/gross_flows.dta", clear
collapse (sum) tot_sales = gross_flows, by(sic87dd_up)
rename sic87dd_up sic87dd
tempfile sales
save "`sales'.dta", replace

* Merge total sales onto each upstream and each downstream industry		
use "`iodir'/clean/flows/gross_flows.dta", clear

foreach d in "down" "up" {
	rename sic87dd_`d' sic87dd
	merge m:1 sic87dd using "`sales'.dta", assert(3) nogenerate
	rename sic87dd sic87dd_`d'
	rename tot_sales tot_sales_`d'
}

* Calculate share of each upstream industry's sales that go to each industry
gen produce_share = gross_flows/tot_sales_up

* Calculate share of each downstream industry's purchases that are from each industry
gen purchase_share = gross_flows/tot_sales_down

label var sic87dd_down "SIC industry purchasing the commodity"
label var sic87dd_up "SIC commodity being purchased"
label var gross_flows "Value of gross flows from upstream to downstream in 1992"
label var tot_sales_down "Total sales by sic87dd_down"
label var tot_sales_up "Total sales by sic87dd_up"
label var produce_share "Share of sic87dd_up's sales that go to sic87dd_down"
label var purchase_share "Cost share of sic87dd_up's good in sic87dd_down's production"

order sic87dd_down sic87dd_up gross_flows tot_sales_down tot_sales_up
sort sic87dd_down

compress
save "`iodir'/clean/shares/gross_shares.dta", replace

/* Use the Leontief inverse to construct matrices that account for higher-order upstream/downstream exposure measures. */

foreach p in "purchase" "produce" {
	* Load the dataset of input output data
	use "`iodir'/clean/shares/gross_shares.dta", clear

	if "`p'" == "purchase" {
		local ivar "sic87dd_up"
		local jvar "sic87dd_down"
		local s "purchase_share"
	}
	else if "`p'" == "produce" {
		local ivar "sic87dd_down"
		local jvar "sic87dd_up"
		local s "produce_share"
	}

	* Convert the dataset into a proper I/O matrix
	keep `ivar' `jvar' `s'
	drop if `ivar' == . | `jvar' == .
	assert `s' >= 0 & `s' < 1

	distinct `ivar'
	assert r(ndistinct) == 479
	distinct `jvar'
	assert r(ndistinct) == 479

	sort `ivar' `jvar'

	quietly levelsof `ivar', clean local(sics)

	reshape wide `s', i(`ivar') j(`jvar')

	mkmat `s'*, matrix(A)

	* Compute the Leontief inverse (subtracting off the identity to exclude "direct" exposure)
	mat leontief = inv(I(479) - A) - I(479)
	mat rownames leontief = `sics'
	mat colnames leontief = `sics'

	drop `s'*
	svmat leontief, names(matcol)
	reshape long leontief, i(`ivar') j(`jvar')
	rename leontief `s'
	
	tempfile leontief_`p'
	save "`leontief_`p''.dta", replace
}

use "`leontief_purchase'.dta", clear
merge 1:1 sic87dd_up sic87dd_down using "`leontief_produce'.dta", assert(3) nogenerate
compress
save "`iodir'/clean/shares/leontief_shares.dta", replace

/*
	Sanity check: the upstream and downstream Leontief exposure measures are related as follows.
	Let i index downstream industries and j index their upstream suppliers.
	Let l_ij denote the (i, j)th element of the upstream Leontief share file.
	Then l_ij should equal l_ji (y_j/y_i) where l_ji is taken from the downstream Leontief share file.
*/

* Calculate total sales made by each industry
use "`iodir'/clean/flows/gross_flows.dta", clear
bysort sic87dd_up: egen tot_sales = total(gross_flows)
keep sic87dd_up tot_sales
rename sic87dd_up sic87dd
duplicates drop
drop if sic87dd == .
tempfile sales
save "`sales'.dta", replace

* Merge total sales by upstream and downstream industries into the downstream Leontief share file
use "`iodir'/clean/shares/leontief_shares.dta", clear
foreach d in "down" "up" {
	rename sic87dd_`d' sic87dd
	merge m:1 sic87dd using "`sales'.dta", assert(3) nogenerate
	rename tot_sales sales_`d'
	rename sic87dd sic87dd_`d'
}

* Compute the quantity l_ji (y_j/y_i)
rename purchase_share l_ij
gen l_ij_check = produce_share * (sales_up/sales_down)
assert l_ij_check != .
keep sic87dd_down sic87dd_up l_ij l_ij_check

* Verify the identity
assert abs(l_ij - l_ij_check) < .01


