/*
	Description: Constructs the main dataset to be used for national-level estimation

	Author: Brendan Price
	Updated: February 2, 2015
*/

version 12.1
set more off
clear all

/* The following scripts should be executed in this sequence (at least once) before running master_builder.do */

do "cbp_us_reader.do"
do "nberces_reader.do"
do "io_flows.do"
do "io_exposure.do"

/* Prepare PCE deflator */

use "../../../dta/pce/pce.dta", clear

forvalues i = 1991/2011 {
	quietly sum pce if year == `i'
	local pce`i' = r(mean)
}

/* Compute total (mfg + non-mfg) employment in 1976 and 1991, as computed in the BLS Current Employment Statistics */

import excel using "../../../dta/bls/ces-total-emp.xlsx", cellrange(A12:M88) firstrow clear
keep if Year == 1976 | Year == 1991
gen totemp = 1000 * (Jan + Feb + Mar + Apr + May + Jun + Jul + Aug + Sep + Oct + Nov + Dec)/12

foreach y of numlist 1976 1991 {
	quietly sum totemp if Year == `y', meanonly
	local totemp`y' = r(mean)
}

/* Prepare the CBP dataset for merge */

* Load CBP data at the desired level of aggregation
use "../../../dta/cbp/national/clean/cbp_merged.dta", clear

* Compute real wage per worker
gen real_wage = real_pay/emp
assert real_wage > 0 & real_wage < .

* Compute workers per establishment
gen emp_estab = emp/estab
assert emp_estab > 0 & emp_estab < .

* Rename so we can retain both CBP and NBER employment/wage bill figures in memory
rename emp cbp_emp
rename real_pay cbp_real_pay
rename nom_pay cbp_nom_pay
rename real_wage cbp_real_wage
rename estab cbp_estab
rename emp_estab cbp_emp_estab

tempfile cbp
save "`cbp'.dta", replace

/* Prepare the NBER-CES data for merge */

use "../../../dta/nberces/clean/nberces_clean.dta", clear

gen reclassified = (sic87dd == 2411 | sic87dd == 2711 | sic87dd == 2721 | sic87dd == 2731 | sic87dd == 2741 | sic87dd == 2771 | sic87dd == 3299 | sic87dd == 3732)

* Shorthand for disregarding the reclassified industries after 1996
local in_sample "(year <= 1996 | reclassified == 0)"

* Compute real wage per worker
gen real_wage = real_pay/emp if `in_sample'
assert real_wage > 0 & real_wage < . if `in_sample'

* Compute real wage per production worker
gen real_prodwage = real_prodpay/prodemp if `in_sample'
assert real_prodwage > 0 & real_prodwage < . if `in_sample'

* Compute real wage per non-production worker
* (note: I drop the assertion because production workers' wage bill sometimes exceeds total wage bill)
gen real_nprodwage = (real_pay - real_prodpay)/(emp - prodemp) if emp > prodemp & `in_sample'
replace real_nprodwage = . if real_nprodwage < 0 & `in_sample'

* Compute production share of total employment
gen prodsh = prodemp/emp if `in_sample'
assert prodsh > 0 & prodsh <= 1 if `in_sample'

* Compute non-production workers employment
gen nprodemp = emp - prodemp if `in_sample'
assert nprodemp >= 0 & nprodemp < . if `in_sample'

* Rename so we can retain both CBP and NBER employment/wage bill figures in memory
foreach v of varlist emp prodemp nprodemp nom_pay nom_prodpay nom_vship nom_vadd nom_matcost nom_invest nom_energy nom_cap real_pay real_prodpay real_vship real_matcost real_invest real_energy real_wage real_prodwage real_nprodwage prodsh piship pimat piinv pien {
rename `v' nber_`v'
}

tempfile nberces
save "`nberces'.dta", replace

/* Combine CBP and NBER-CES datasets */

* Combine the datasets
use "`cbp'.dta", clear
merge 1:1 year sic87dd using "`nberces'.dta", gen(nber_merge)
gen manuf = (sic87dd >= 2000 & sic87dd <= 3999)
assert nber_merge == 3 if manuf == 1 & (year >= 1988 & year <= 2009)
drop nber_merge
	
* Re-create the indicator for industries reclassified into non-manufacturing
rename reclassified reclassified_temp
bysort sic87dd: egen reclassified = max(reclassified == 1)
drop reclassified_temp

merge m:1 sic87dd using "../../../xwalks/ind/sic87_sic87dd/sic87dd_key.dta", assert(3) nogenerate

/* Reshape to one observation per industry */

reshape wide cbp* nber*, i(sic87dd) j(year)

order sic87dd sic87dd_desc manuf reclassified cbp_emp* cbp_real_pay* cbp_nom_pay* cbp_real_wage* cbp_estab* cbp_emp_estab* nber_emp* nber_prodemp* nber_nprodemp* nber_nom_pay* nber_nom_prodpay* nber_nom_vship* nber_nom_vadd* nber_nom_matcost* nber_nom_invest* nber_nom_energy* nber_nom_cap* nber_real_pay* nber_real_prodpay* nber_real_vship* nber_real_matcost* nber_real_invest* nber_real_energy* nber_real_wage* nber_real_prodwage* nber_real_nprodwage* nber_prodsh* nber_piship* nber_pimat* nber_piinv* nber_pien*

/* Handle trade data: merge in and annualize */

* Merge in trade data
merge 1:1 sic87dd using "../../../dta/trade/trade_variables.dta", assert(1 3) gen(trade_merge)
assert trade_merge == 3 if manuf == 1
assert trade_merge == 1 if manuf == 0
drop trade_merge

* Annualizing growth rates
foreach t in "1991_1999" "1991_2007" "1991_2009" "1991_2011" "1999_2007" "1999_2009" "1999_2011" "2007_2011" {
	local start = substr("`t'", 1, 4)
	local end = substr("`t'", 6, 4)

	foreach d in "import" "export" "net_import" {
		replace d_`d'_usch_`t' = d_`d'_usch_`t'/(`end' - `start')
		replace d_`d'_otch_`t' = d_`d'_otch_`t'/(`end' - `start')
	}
}

* Compute real US market volume (= shipments + net imports, in 2007 dollars)
forvalues i = 1991/2011 {
	* I deflate each industry's shipments using the PCE, rather than industry-specific deflators.
	if `i' <= 1996 {
		gen real_market`i' = (nber_nom_vship`i'/`pce`i'') + real_netimports_us_`i'
	}
	else if `i' >= 1997 & `i' <= 2009 {
		gen real_market`i' = (nber_nom_vship`i'/`pce`i'') + real_netimports_us_`i' if reclassified == 0
	}
}

/* Handle measures of upstream and downstream import exposure: merge in and annualize. */

merge 1:1 sic87dd using "../../../dta/io/clean/exposure/first_order_exposure.dta", assert(3) nogenerate
merge 1:1 sic87dd using "../../../dta/io/clean/exposure/leontief_exposure.dta", assert(3) nogenerate

* Annualizing the exposure measures
foreach t in "1991_1999" "1991_2007" "1991_2009" "1991_2011" "1999_2007" "1999_2009" "1999_2011" "2007_2011" {
	local start = substr("`t'", 1, 4)
	local end = substr("`t'", 6, 4)

	foreach s in "up" "down" {
		foreach c in "usch" "otch" {
			* "First-order" measures of upstream/downstream import exposure
			replace d_`s'_`c'_`t' = d_`s'_`c'_`t' / (`end' - `start')

			* Higher-order (Leontief) measures of upstream/downstream import exposure
			replace d_`s'_LT_`c'_`t' = d_`s'_LT_`c'_`t' / (`end' - `start')
		}
	}
}

/* Handle control variables */

* Merge in 1-digit manufacturing sector dummies
merge 1:1 sic87dd using "../../../dta/controls/mfg_sector_dummies.dta", assert(1 3) generate(sector_merge)
assert sector_merge == 3 if manuf == 1
assert sector_merge == 1 if manuf == 0
drop sector_merge

* Merge in data on computer and high-tech shares of investment
merge 1:1 sic87dd using "../../../dta/controls/investment_controls.dta", assert(1 3) generate(sector_merge)
assert sector_merge == 3 if manuf == 1
assert sector_merge == 1 if manuf == 0
drop sector_merge

* Construct computed from the NBER data
gen ind_lnavgw_1991 = log(nber_real_pay1991/nber_emp1991) if manuf == 1
label variable ind_lnavgw_1991 "Log average wage in 1991 (in 2007 $)"

gen d_ind_lnavgw_7691 = 100 * (log(nber_real_pay1991/nber_emp1991) - log(nber_real_pay1976/nber_emp1976)) if manuf == 1
label variable d_ind_lnavgw_7691 "Change in log real wage (1976-1991)"

gen ind_prodwemp_1991 = 100 * (nber_prodemp1991/nber_emp1991)
label variable ind_prodwemp_1991 "Production workers share of employment (1991)"

gen ind_capvadd_1991 = nber_nom_cap1991/nber_nom_vadd1991
label variable ind_capvadd_1991 "Capital/value added (1991)"

gen d_ind_shemp_7691 = 100 * ((nber_emp1991/`totemp1991') - (nber_emp1976/`totemp1976'))
label variable d_ind_shemp_7691 "Change in industry share of total employment (1976-1991)"

* Merge in 3-digit codes for use in clustering standard errors
merge 1:1 sic87dd using "../../../xwalks/ind/sic3/sic87dd_sic3.dta", assert(3) nogenerate

/* Construct outcome variables */

foreach d in "cbp" "nber" {
	foreach v in "emp" "real_pay" "nom_pay" "real_wage" "estab" "emp_estab" "prodemp" "nprodemp" "real_prodpay" "nom_prodpay" "real_prodwage" "real_nprodwage" "nom_vship" "real_vship" "nom_vadd" "piship" {
		* CBP doesn't have output data
		if "`d'" == "cbp" & ("`v'" != "emp" & "`v'" != "real_pay" & "`v'" != "nom_pay" & "`v'" != "real_wage" & "`v'" != "estab"  & "`v'" != "emp_estab") {
			continue
		}
		
		* NBER doesn't have number of establishments
		if "`d'" == "nber" & ("`v'" == "estab" | "`v'" == "emp_estab") {
			continue
		}

		* For NBER outcomes: skip industries that are reclassified into non-manufacturing under NAICS
		if "`d'" == "cbp" {
			local dlab "CBP"
			local in_sample "1"
		}
		else {
			local dlab "NBER"
			local in_sample "reclassified == 0"
		}
	
		if "`v'" == "emp" {
			local vlab "employment"
		}
		else if "`v'" == "real_pay" {
			local vlab "real wage bill"
		}
		else if "`v'" == "nom_pay" {
			local vlab "nominal wage bill"
		}
		else if "`v'" == "real_wage" {
			local vlab "real wage"
		}
		else if "`v'" == "estab" {
			local vlab "number of establishments"
		}
		else if "`v'" == "emp_estab" {
			local vlab "workers per establishment"
		}
		else if "`v'" == "prodemp" {
			local vlab "employment of production workers"
		}
		else if "`v'" == "nprodemp" {
			local vlab "employment of non-production workers"
		}
		else if "`v'" == "real_prodpay" {
			local vlab "real production worker wage bill"
		}
		else if "`v'" == "nom_prodpay" {
			local vlab "nominal production worker wage bill"
		}
		else if "`v'" == "real_prodwage" {
			local vlab "real production wage"
		}
		else if "`v'" == "real_nprodwage" {
			local vlab "real non-production wage"
		}
		else if "`v'" == "nom_vship" {
			local vlab "nominal value of shipments"
		}
		else if "`v'" == "real_vship" {
			local vlab "real value of shipments"
		}
		else if "`v'" == "nom_vadd" {
			local vlab "nominal value added"
		}
		else if "`v'" == "piship" {
			local vlab "shipments deflator"
		}

		foreach span in "1991_2011" "1991_2007" "1991_2009" "1991_1999" "1999_2007" "2007_2009" "2007_2011" "1999_2009" "1999_2011" {
			local start = substr("`span'", 1, 4)
			local end = substr("`span'", 6, 4)

			* Last year: 2011 for CBP, 2009 for NBER
			if "`d'" == "cbp" & "`end'" == "2009" {
				continue
			}
			else if "`d'" == "nber" & "`end'" == "2011" {
				continue
			}

			* Compute annualized growth rates
			gen dl_`d'_`v'_`start'_`end' = 100 * (log(`d'_`v'`end') - log(`d'_`v'`start')) / (`end' - `start') if `in_sample'
			label var dl_`d'_`v'_`start'_`end' "Annualized change in `vlab' (`dlab'), `start'-`end'"
		}
	}
}

* Save the cleaned/merged dataset
compress
save "../../../dta/sample/main.dta", replace


