/*
	Description: Creates Appendix Table 2 (import effects on industry shipments and output prices)

	Author: Brendan Price
	Updated: July 30, 2014
*/

version 12.1
set more off
clear all
capture restore, not

local outdir "../../out"

* Load the estimation sample
use "../../dta/sample/main.dta", clear

* Restrict to manufacturing industries that aren't reclassified into non-manufacturing under NAICS
keep if manuf == 1 & reclassified == 0

* Specify controls
local sectors "sector2 sector3 sector4 sector5 sector6 sector7 sector8 sector9 sector10"

* Define the computer sector (essentially NAICS 334, following Houseman et al. and AADHP 2014)
gen comp_broad = 0
replace comp_broad = 1 if (sic87dd >= 3570 & sic87dd <= 3579) & (sic87dd != 3579)
replace comp_broad = 1 if (sic87dd == 3651 | sic87dd == 3652)
replace comp_broad = 1 if (sic87dd >= 3660 & sic87dd <= 3669)
replace comp_broad = 1 if (sic87dd >= 3670 & sic87dd <= 3679)
replace comp_broad = 1 if (sic87dd == 3695)
replace comp_broad = 1 if (sic87dd == 3812 | sic87dd == 3822 | sic87dd == 3823 | sic87dd == 3824 | sic87dd == 3825 | sic87dd == 3826 | sic87dd == 3829 | sic87dd == 3844 | sic87dd == 3845 | sic87dd == 3873)

* Restrict to variables we need
#delimit ;
keep sic87dd sic3 nber_emp1991 comp_broad `sectors'
	d_import_usch_1991_1999 d_import_usch_1999_2009
	d_import_otch_1991_1999 d_import_otch_1999_2009
	dl_nber_nom_vship_1991_1999 dl_nber_nom_vship_1999_2009
	dl_nber_real_vship_1991_1999 dl_nber_real_vship_1999_2009
	dl_nber_piship_1991_1999 dl_nber_piship_1999_2009;
#delimit cr

* Stacked first differences
reshape long d_import_usch_ d_import_otch_ dl_nber_nom_vship_ dl_nber_real_vship_ dl_nber_piship_, i(sic87dd) j(period) string

foreach v in "d_import_usch" "d_import_otch" "dl_nber_nom_vship" "dl_nber_real_vship" "dl_nber_piship" {
	rename `v'_ `v'
}

rename dl_nber_nom_vship dl_nom_vship
rename dl_nber_real_vship dl_real_vship
rename dl_nber_piship dl_piship

* Time dummies
gen t1 = (period == "1991_1999")
gen t2 = (period == "1999_2009")

* Label regressors
label var t1 "1{1991-1999}"
label var t2 "1{1999-2009}"

label var dl_nom_vship "Nominal Shipments"
label var dl_real_vship "Real Shipments"
label var dl_piship "Shipments Deflator"
label var d_import_usch "Direct Trade Shock"

* Specify clustering and weighting
local options "noconstant vce(cluster sic3)"
local aw "[aw = nber_emp1991]"

* Demean control variables to facilitate interpretation of constants
foreach var of varlist `sectors' {
	forvalues i = 1/2 {
		quietly sum `var' if t`i' == 1 `aw'
		replace `var' = `var' - r(mean) if t`i' == 1
	}
}

/* Regression specifications with and without the computer-producing sector (following AADHP AER P&P 2014) */

forvalues exclude_comp = 0/1 {
	estimates clear

	if `exclude_comp' == 0 {
		local if_cond ""
	}
	else if `exclude_comp' == 1 {
		local if_cond "if comp_broad == 0"
	}

	foreach v in "nom_vship" "real_vship" "piship" {
		eststo m_`v': quietly ivregress 2sls dl_`v' t1 t2 `sectors' (d_import_usch = d_import_otch) `if_cond' `aw', `options'
	}

	* Print out the regression results
	tempfile specs

	#delimit ;
	esttab * using "`specs'.csv",
		depvars
		b(%9.2f) se(%9.2f)
		star(* .10 ** .05 *** .01)
		title("Effect of Import Competition on Industry Output")
		nonotes
		indicate("1-Digit Mfg Sector Controls = `sectors'")
		keep(d_import_usch)
		label
		stats(N, labels("N") fmt(0))
		replace;
	#delimit cr

	* Save the results
	if `exclude_comp' == 0 {
		preserve
		insheet using "`specs'.csv", comma clear
		export excel "`outdir'/AADHP-JOLE-Appendix.xlsx", sheetreplace sheet(AppTab2_Raw)
		restore
	}
	else if `exclude_comp' == 1 {
		preserve
		insheet using "`specs'.csv", comma clear
		export excel "`outdir'/AADHP-JOLE-Appendix.xlsx", sheetmodify cell(A15) sheet(AppTab2_Raw)
		restore
	}
}

