/*
	Description: Runs a model reported in the paper's conclusion: a regression of 2007-2011 employment changes on changes in exposure to Chinese imports over 1999-2007 and 2007-2011.
	
	Author: Brendan Price
	Updated: August 5, 2014
*/

version 12.1
set more off
clear all
capture log close

local outdir "../../out/auxiliary"

* Load the estimation sample
use "../../dta/sample/main.dta", clear

* Restrict to manufacturing
keep if manuf == 1

* Specify controls for 1-digit sectors
local sectors "sector2 sector3 sector4 sector5 sector6 sector7 sector8 sector9 sector10"

* Restrict to variables we need
keep sic87dd sic3 cbp_emp1991 `sectors' dl_cbp_emp_2007_2011 d_import_usch_1999_2007 d_import_usch_2007_2011 d_import_otch_1999_2007 d_import_otch_2007_2011

label var d_import_usch_1999_2007 "Change in Import Exposure, 1999-2007"
label var d_import_usch_2007_2011 "Change in Import Exposure, 2007-2011"

* Specify weighting and clustering
local aw "[aw = cbp_emp1991]"
local vce "vce(cluster sic3)"

* Demean covariates so that the constant is interpretable
foreach var of varlist `sectors' {
	quietly sum `var' `aw'
	replace `var' = `var' - r(mean)
}

* Run the specification, without and then with 1-digit manufacturing sector dummies
estimates clear
eststo m1: quietly ivregress 2sls dl_cbp_emp_2007_2011 (d_import_usch_1999_2007 d_import_usch_2007_2011 = d_import_otch_1999_2007 d_import_otch_2007_2011) `aw', `vce'
eststo m2: quietly ivregress 2sls dl_cbp_emp_2007_2011 `sectors' (d_import_usch_1999_2007 d_import_usch_2007_2011 = d_import_otch_1999_2007 d_import_otch_2007_2011) `aw', `vce'

log using "`outdir'/recession.txt", text replace

#delimit ;
esttab,
	title("Lagged Effect of Import Exposure on 2007-2011 Employment Changes")
	nodepvars
	collabels(, none)
	mlabels(, none)
	keep(d_import_usch_1999_2007 d_import_usch_2007_2011 _cons)
	b(%9.2f) se(%9.2f)
	star(* .10 ** .05 *** .01)
	label
	varwidth(40)
	indicate("1-Digit Mfg Sector Dummies = `sectors'")
	stats(N, fmt(0))
	note("Changes in US import exposure are instrumented per the text.");
#delimit cr

log close

