/*
	Description: Creates Table 2 (OLS and 2SLS effects of import competition on manufacturing employment)

	Author: Brendan Price
	Updated: July 30, 2014
*/

version 12.1
set more off
clear all

local outdir "../../out"

* Partial R-squared factor used to "discount" implied employment changes
local pfactor = .56

* Predict implied employment change
capture program drop compute_changes
program define compute_changes
	quietly levelsof period, local(periods)
	
	foreach t of local periods {
		egen pred_d_emp_`t' = total(pred_d_emp * (period == "`t'"))
		quietly sum pred_d_emp_`t'
		estadd scalar pred_d_emp_`t' = r(mean)
		drop pred_d_emp_`t'
	}
end

/* Table 2 columns 1-4: stacked first differences */

use "../../dta/sample/main.dta", clear

* Restrict to manufacturing
keep if manuf == 1

* Restrict to variables we need
#delimit ;
keep sic87dd sic3 cbp_emp1991 cbp_emp1999 cbp_emp2007 cbp_emp2011
	dl_cbp_emp_1991_1999 dl_cbp_emp_1999_2011 dl_cbp_emp_1999_2007
	d_import_usch_1991_1999 d_import_usch_1999_2011 d_import_usch_1999_2007
	d_import_otch_1991_1999 d_import_otch_1999_2011 d_import_otch_1999_2007;
#delimit cr

* Stacked first differences
reshape long dl_cbp_emp_ d_import_usch_ d_import_otch_, i(sic87dd) j(period) string
rename dl_cbp_emp_ dl_cbp_emp
rename d_import_usch_ d_import_usch
rename d_import_otch_ d_import_otch	

* Time dummies
gen t9199 = (period == "1991_1999")
gen t9911 = (period == "1999_2011")
gen t9907 = (period == "1999_2007")

* End-of-period employment for use in employment calculations
gen L1 = cbp_emp1999 if period == "1991_1999"
replace L1 = cbp_emp2011 if period == "1999_2011"
replace L1 = cbp_emp2007 if period == "1999_2007"
assert L1 != .

* Factors needed to rescale coefficients (to undo multiplication by 100 and also annualization)
gen lambda = 100 / (1999 - 1991) if period == "1991_1999"
replace lambda = 100 / (2011 - 1999) if period == "1999_2011"
replace lambda = 100 / (2007 - 1999) if period == "1999_2007"
assert lambda != .

* Variable to record employment losses
gen pred_d_emp = .

* Specify weighting and clustering
local aw "[aw = cbp_emp1991]"
local vce "vce(cluster sic3)"

tempfile core
save "`core'.dta", replace

* Specifications in first differences: 1991-1999 + 1999-2011
estimates clear

use "`core'.dta", clear
keep if period == "1991_1999" | period == "1999_2011"

eststo m1: quietly reg dl_cbp_emp t9199 t9911 `aw', noconstant `vce'
estadd local span "1991-2011"
estadd local method "OLS"

eststo m2: quietly reg dl_cbp_emp d_import_usch t9199 t9911 `aw', noconstant `vce'
estadd local span "1991-2011"
estadd local method "OLS"

eststo m3: quietly ivregress 2sls dl_cbp_emp t9199 t9911 (d_import_usch = d_import_otch) `aw', noconstant `vce'
estadd local span "1991-2011"
estadd local method "2SLS"

* Compute implied employment losses
replace pred_d_emp = L1 * (1 - exp(-1 * (1/lambda) * (_b[d_import_usch] * `pfactor' * d_import_usch)))
compute_changes

* Specifications in first differences: 1991-1999 + 1999-2007
use "`core'.dta", clear
keep if period == "1991_1999" | period == "1999_2007"

eststo m4: quietly ivregress 2sls dl_cbp_emp t9199 t9907 (d_import_usch = d_import_otch) `aw', noconstant `vce'
estadd local span "1991-2007"
estadd local method "2SLS"

* Compute implied employment losses
replace pred_d_emp = L1 * (1 - exp(-1 * (1/lambda) * (_b[d_import_usch] * `pfactor' * d_import_usch)))
compute_changes

/*
	Table 2 Columns 5-8
	Separately by period
*/

use "../../dta/sample/main.dta", clear

* Restrict to manufacturing
keep if manuf == 1

* Recreate and label the time effects so variable labels appear in the printed table
gen t9199 = .
gen t9911 = .
gen t9907 = .

label var t9199 "1{1991-1999}"
label var t9911 "1{1999-2011}"
label var t9907 "1{1999-2007}"

foreach t in "1991_1999" "1999_2011" "1999_2007" "1991_2011" {
	local start = substr("`t'", 1, 4)
	local end = substr("`t'", 6, 4)

	* Specify outcome/regressor/instrument
	local yvar "dl_cbp_emp_`t'"
	local xvar "d_import_usch_`t'"
	local ivvar "d_import_otch_`t'"

	* Specify weighting and clustering
	local aw "[aw = cbp_emp1991]"
	local vce "vce(cluster sic3)"

	* Recreate regressor: this forces esttab to display the same regressor for each model
	capture drop d_import_usch
	gen d_import_usch = `xvar'
	label var d_import_usch "Change in US imports from China"

	* Spec
	eststo m_`t': quietly ivregress 2sls `yvar' (d_import_usch = `ivvar') `aw', `vce'
	estadd local span "`start'-`end'"
	estadd local method "2SLS"
}
	
tempfile specs

#delimit ;
esttab * using "`specs'.csv",
	nodepvars
	collabels(, none)
	mlabels("Stacked Differences" "Stacked Differences" "Stacked Differences" "Stacked Differences" "Long Difference" "Long Difference" "Long Difference" "Long Difference")
	order(d_import_usch t9199 t9911 t9907 _cons)
	b(%9.2f) se(%9.2f)
	star(* .10 ** .05 *** .01)
	nonotes
	label
	stats(method span N pred_d_emp_1991_1999 pred_d_emp_1999_2011 pred_d_emp_1999_2007, labels("Estimation Method" "Period" "N" "Pred Emp Change, 1991-1999" "Pred Emp Change, 1999-2011" "Pred Emp Change, 1999-2007") fmt(0))
	replace;
#delimit cr

* Switch the output to Excel format
insheet using "`specs'.csv", comma clear
export excel "`outdir'/AADHP-JOLE-Tables.xlsx", sheetreplace sheet(Tab2_Raw)



