/*
	Description: Creates Table 5 (effects of import competition on a number of labor market outcomes)

	Author: Brendan Price
	Updated: July 30, 2014
*/

version 12.1
set more off
clear all

local outdir "../../out"

* Load the estimation sample
use "../../dta/sample/main.dta", clear

* Restrict to manufacturing
keep if manuf == 1

* Specify controls
local sector_controls "sector2 sector3 sector4 sector5 sector6 sector7 sector8 sector9 sector10"

* Restrict to variables we need
#delimit ;
keep sic87dd sic3 cbp_emp1991 nber_emp1991 `sector_controls'
	d_import_usch_1991_1999 d_import_usch_1999_2011 d_import_usch_1999_2009
	d_import_otch_1991_1999 d_import_otch_1999_2011 d_import_otch_1999_2009

	dl_cbp_emp_1991_1999 dl_cbp_emp_1999_2011
	dl_cbp_real_pay_1991_1999 dl_cbp_real_pay_1999_2011
	dl_cbp_real_wage_1991_1999 dl_cbp_real_wage_1999_2011
	dl_cbp_estab_1991_1999 dl_cbp_estab_1999_2011
	dl_cbp_emp_estab_1991_1999 dl_cbp_emp_estab_1999_2011

	dl_nber_emp_1991_1999 dl_nber_emp_1999_2009
	dl_nber_real_pay_1991_1999 dl_nber_real_pay_1999_2009
	dl_nber_real_wage_1991_1999 dl_nber_real_wage_1999_2009
	dl_nber_prodemp_1991_1999 dl_nber_prodemp_1999_2009
	dl_nber_nprodemp_1991_1999 dl_nber_nprodemp_1999_2009
	dl_nber_real_prodwage_1991_1999 dl_nber_real_prodwage_1999_2009
	dl_nber_real_nprodwage_1991_1999 dl_nber_real_nprodwage_1999_2009;
#delimit cr

* Stacked first differences
reshape long dl_cbp_emp_ d_import_usch_ d_import_otch_ dl_cbp_real_pay_ dl_cbp_real_wage_ dl_cbp_estab_ dl_cbp_emp_estab_ dl_nber_emp_ dl_nber_real_pay_ dl_nber_real_wage_ dl_nber_prodemp_ dl_nber_nprodemp_ dl_nber_real_prodwage_ dl_nber_real_nprodwage_, i(sic87dd) j(period) string

foreach v in "dl_cbp_emp" "d_import_usch" "d_import_otch" "dl_cbp_real_pay" "dl_cbp_real_wage" "dl_cbp_estab" "dl_cbp_emp_estab" "dl_nber_emp" "dl_nber_real_pay" "dl_nber_real_wage" "dl_nber_prodemp" "dl_nber_nprodemp" "dl_nber_real_prodwage" "dl_nber_real_nprodwage" {
	rename `v'_ `v'
}

* Time dummies
gen t1 = (period == "1991_1999")
gen t2 = (period == "1999_2011") | (period == "1999_2009")

* Indicate which observations should be used in relation to which outcomes
gen cbp = (period == "1991_1999" | period == "1999_2011")
gen nber = (period == "1991_1999" | period == "1999_2009")

* Label regressors
label var t1 "1{1991-1999}"
label var t2 "1{1999-2009/2011}"

label var dl_cbp_emp "Emp."
label var dl_cbp_real_pay "Real Wage Bill"
label var dl_cbp_real_wage "Real Wage"
label var dl_cbp_estab "Num Estabs."
label var dl_cbp_emp_estab "Emp Per Estab."

label var dl_nber_emp "Emp."
label var dl_nber_real_pay "Real Wage Bill"
label var dl_nber_real_wage "Real Wage"
label var dl_nber_prodemp "Prod. Emp."
label var dl_nber_nprodemp "Non-Prod. Emp."
label var dl_nber_real_prodwage "Real Prod. Wage"
label var dl_nber_real_nprodwage "Real Non-Prod. Wage"

label var d_import_usch "Change in U.S. imports from China"

* Specify clustering
local options "noconstant vce(cluster sic3)"

estimates clear

foreach v in "cbp_emp" "cbp_estab" "cbp_emp_estab" "cbp_real_pay" "cbp_real_wage" "nber_prodemp" "nber_nprodemp" "nber_real_prodwage" "nber_real_nprodwage" "nber_emp" "nber_real_pay" "nber_real_wage" {
	if regexm("`v'", "cbp") {
		local aw "[aw = cbp_emp1991]"
		local if_cond "cbp == 1"
	}
	else {
		local aw "[aw = nber_emp1991]"
		local if_cond "nber == 1"
	}

	* Demean control variables to facilitate interpretation of constants
	foreach var of varlist `sector_controls' {
		forvalues i = 1/2 {
			quietly sum `var' if t`i' == 1 & `if_cond' `aw'
			replace `var' = `var' - r(mean) if t`i' == 1 & `if_cond'
		}
	}

	* Specify outcome/regressor/instrument
	local yvar "dl_`v'"
	local xvar "d_import_usch"
	local ivvar "d_import_otch"

	* Regression (with sector controls)
	eststo reg_`v': quietly ivregress 2sls `yvar' t1 t2 `sector_controls' (`xvar' = `ivvar') if `if_cond' `aw', `options'
	
	* Report time effects only
	eststo means_`v': quietly reg `yvar' t1 t2 `sector_controls' if `if_cond' `aw', `options'
}

* Report regression results and time effects in separate panels
tempfile specs
tempfile means

#delimit ;
esttab reg_* using "`specs'.csv",
	depvars
	mgroups("CBP" "NBER", pattern(1 0 0 0 0 1 0 0 0 0 0 0))
	b(%9.2f) se(%9.2f)
	star(* .10 ** .05 *** .01)
	title("Effect of Import Competition on Labor-Market Outcomes")
	nonotes
	indicate("Sector Controls = `sector_controls'")
	order(`xvar' t1 t2)
	label
	stats(N, labels("N") fmt(0))
	replace;
#delimit cr

#delimit ;
esttab means_* using "`means'.csv",
	depvars
	mgroups("CBP" "NBER", pattern(1 0 0 0 0 1 0 0 0 0 0 0))
	b(%9.2f) se(%9.2f)
	star(* .10 ** .05 *** .01)
	title("Effect of Import Competition on Labor-Market Outcomes")
	nonotes
	indicate("Sector Controls = `sector_controls'")
	order(t1 t2)
	label
	stats(N, labels("N") fmt(0))
	replace;
#delimit cr

* Convert the output into Excel format
insheet using "`specs'.csv", comma clear
export excel "`outdir'/AADHP-JOLE-Tables.xlsx", sheetreplace sheet(Tab5_Raw)

insheet using "`means'.csv", comma clear
export excel "`outdir'/AADHP-JOLE-Tables.xlsx", sheetmodify cell(A15) sheet(Tab5_Raw)



